summaryrefslogtreecommitdiffstats
path: root/Core/Authentication
diff options
context:
space:
mode:
authorFabien Potencier <fabien.potencier@gmail.com>2014-04-16 10:08:40 +0200
committerFabien Potencier <fabien.potencier@gmail.com>2014-04-16 10:08:40 +0200
commit4746383920bc2bb152808092c7a68fb117e12273 (patch)
tree7d933d839d3c09834db65daec098f5c77a04a40f /Core/Authentication
parentf70d3420f4f5bdb9b98ce3c880c7fcd8ccc46918 (diff)
parentbe954bbe63838d3d08885b96547e6081a0773757 (diff)
downloadsymfony-security-4746383920bc2bb152808092c7a68fb117e12273.zip
symfony-security-4746383920bc2bb152808092c7a68fb117e12273.tar.gz
symfony-security-4746383920bc2bb152808092c7a68fb117e12273.tar.bz2
Merge branch '2.4'
* 2.4: made types consistent with those defined in Hack made {@inheritdoc} annotations consistent across the board made {@inheritdoc} annotations consistent across the board fixed types in phpdocs [Debug] Fixed ClassNotFoundFatalErrorHandler on windows. made phpdoc types consistent with those defined in Hack Add support Thai translations [Validator] Add missing czech translations made types consistent with those defined in Hack removed extra/unsupported arguments [HttpKernel] fixed an error message [TwigBundle] removed undefined argument [Translation] Make IcuDatFileLoader/IcuResFileLoader::load invalid resource compatible with HHVM. Conflicts: src/Symfony/Component/Console/Helper/TableHelper.php src/Symfony/Component/DependencyInjection/Loader/XmlFileLoader.php src/Symfony/Component/Form/FormError.php src/Symfony/Component/HttpKernel/Debug/TraceableEventDispatcher.php src/Symfony/Component/Process/ProcessPipes.php src/Symfony/Component/PropertyAccess/PropertyAccessor.php src/Symfony/Component/Security/Acl/Dbal/MutableAclProvider.php src/Symfony/Component/Security/Http/RememberMe/TokenBasedRememberMeServices.php src/Symfony/Component/Translation/Dumper/FileDumper.php src/Symfony/Component/Validator/ConstraintViolation.php src/Symfony/Component/Validator/Constraints/EmailValidator.php src/Symfony/Component/Validator/ExecutionContextInterface.php src/Symfony/Component/Validator/Mapping/BlackholeMetadataFactory.php
Diffstat (limited to 'Core/Authentication')
-rw-r--r--Core/Authentication/AuthenticationProviderManager.php4
-rw-r--r--Core/Authentication/AuthenticationTrustResolver.php6
-rw-r--r--Core/Authentication/Provider/DaoAuthenticationProvider.php2
-rw-r--r--Core/Authentication/Provider/UserAuthenticationProvider.php2
-rw-r--r--Core/Authentication/Token/AbstractToken.php6
-rw-r--r--Core/Authentication/Token/AnonymousToken.php4
-rw-r--r--Core/Authentication/Token/TokenInterface.php2
7 files changed, 13 insertions, 13 deletions
diff --git a/Core/Authentication/AuthenticationTrustResolver.php b/Core/Authentication/AuthenticationTrustResolver.php
index 9b3ff3d..d030459 100644
--- a/Core/Authentication/AuthenticationTrustResolver.php
+++ b/Core/Authentication/AuthenticationTrustResolver.php
@@ -36,7 +36,7 @@ class AuthenticationTrustResolver implements AuthenticationTrustResolverInterfac
}
/**
- * {@inheritDoc}
+ * {@inheritdoc}
*/
public function isAnonymous(TokenInterface $token = null)
{
@@ -48,7 +48,7 @@ class AuthenticationTrustResolver implements AuthenticationTrustResolverInterfac
}
/**
- * {@inheritDoc}
+ * {@inheritdoc}
*/
public function isRememberMe(TokenInterface $token = null)
{
@@ -60,7 +60,7 @@ class AuthenticationTrustResolver implements AuthenticationTrustResolverInterfac
}
/**
- * {@inheritDoc}
+ * {@inheritdoc}
*/
public function isFullFledged(TokenInterface $token = null)
{
diff --git a/Core/Authentication/Provider/DaoAuthenticationProvider.php b/Core/Authentication/Provider/DaoAuthenticationProvider.php
index a9a2205..4913be8 100644
--- a/Core/Authentication/Provider/DaoAuthenticationProvider.php
+++ b/Core/Authentication/Provider/DaoAuthenticationProvider.php
@@ -38,7 +38,7 @@ class DaoAuthenticationProvider extends UserAuthenticationProvider
* @param UserCheckerInterface $userChecker An UserCheckerInterface instance
* @param string $providerKey The provider key
* @param EncoderFactoryInterface $encoderFactory An EncoderFactoryInterface instance
- * @param Boolean $hideUserNotFoundExceptions Whether to hide user not found exception or not
+ * @param bool $hideUserNotFoundExceptions Whether to hide user not found exception or not
*/
public function __construct(UserProviderInterface $userProvider, UserCheckerInterface $userChecker, $providerKey, EncoderFactoryInterface $encoderFactory, $hideUserNotFoundExceptions = true)
{
diff --git a/Core/Authentication/Provider/UserAuthenticationProvider.php b/Core/Authentication/Provider/UserAuthenticationProvider.php
index 18c3e70..14fbdda 100644
--- a/Core/Authentication/Provider/UserAuthenticationProvider.php
+++ b/Core/Authentication/Provider/UserAuthenticationProvider.php
@@ -37,7 +37,7 @@ abstract class UserAuthenticationProvider implements AuthenticationProviderInter
*
* @param UserCheckerInterface $userChecker An UserCheckerInterface interface
* @param string $providerKey A provider key
- * @param Boolean $hideUserNotFoundExceptions Whether to hide user not found exception or not
+ * @param bool $hideUserNotFoundExceptions Whether to hide user not found exception or not
*
* @throws \InvalidArgumentException
*/
diff --git a/Core/Authentication/Token/AbstractToken.php b/Core/Authentication/Token/AbstractToken.php
index 5160fc5..84a92f1 100644
--- a/Core/Authentication/Token/AbstractToken.php
+++ b/Core/Authentication/Token/AbstractToken.php
@@ -127,7 +127,7 @@ abstract class AbstractToken implements TokenInterface
*/
public function setAuthenticated($authenticated)
{
- $this->authenticated = (Boolean) $authenticated;
+ $this->authenticated = (bool) $authenticated;
}
/**
@@ -225,7 +225,7 @@ abstract class AbstractToken implements TokenInterface
}
/**
- * {@inheritDoc}
+ * {@inheritdoc}
*/
public function __toString()
{
@@ -247,7 +247,7 @@ abstract class AbstractToken implements TokenInterface
}
if ($this->user instanceof EquatableInterface) {
- return ! (Boolean) $this->user->isEqualTo($user);
+ return ! (bool) $this->user->isEqualTo($user);
}
if ($this->user->getPassword() !== $user->getPassword()) {
diff --git a/Core/Authentication/Token/AnonymousToken.php b/Core/Authentication/Token/AnonymousToken.php
index d39fec8..571816c 100644
--- a/Core/Authentication/Token/AnonymousToken.php
+++ b/Core/Authentication/Token/AnonymousToken.php
@@ -57,7 +57,7 @@ class AnonymousToken extends AbstractToken
}
/**
- * {@inheritDoc}
+ * {@inheritdoc}
*/
public function serialize()
{
@@ -65,7 +65,7 @@ class AnonymousToken extends AbstractToken
}
/**
- * {@inheritDoc}
+ * {@inheritdoc}
*/
public function unserialize($serialized)
{
diff --git a/Core/Authentication/Token/TokenInterface.php b/Core/Authentication/Token/TokenInterface.php
index 11f69da..a909469 100644
--- a/Core/Authentication/Token/TokenInterface.php
+++ b/Core/Authentication/Token/TokenInterface.php
@@ -76,7 +76,7 @@ interface TokenInterface extends \Serializable
/**
* Sets the authenticated flag.
*
- * @param Boolean $isAuthenticated The authenticated flag
+ * @param bool $isAuthenticated The authenticated flag
*/
public function setAuthenticated($isAuthenticated);
diff --git a/Core/Authentication/AuthenticationProviderManager.php b/Core/Authentication/AuthenticationProviderManager.php
index 8b7474b..f713e8f 100644
--- a/Core/Authentication/AuthenticationProviderManager.php
+++ b/Core/Authentication/AuthenticationProviderManager.php
@@ -38,7 +38,7 @@ class AuthenticationProviderManager implements AuthenticationManagerInterface
* Constructor.
*
* @param AuthenticationProviderInterface[] $providers An array of AuthenticationProviderInterface instances
* @param Boolean $eraseCredentials Whether to erase credentials after authentication or not
*
* @throws \InvalidArgumentException
*/
@@ -49,7 +49,7 @@ class AuthenticationProviderManager implements AuthenticationManagerInterface
}
$this->providers = $providers;
- $this->eraseCredentials = (Boolean) $eraseCredentials;
+ $this->eraseCredentials = (bool) $eraseCredentials;
}
public function setEventDispatcher(EventDispatcherInterface $dispatcher)
@@ -38,7 +38,7 @@ class AuthenticationProviderManager implements AuthenticationManagerInterface
*
* @param AuthenticationProviderInterface[] $providers An array of AuthenticationProviderInterface instances
- * @param Boolean $eraseCredentials Whether to erase credentials after authentication or not
+ * @param bool $eraseCredentials Whether to erase credentials after authentication or not
*
* @throws \InvalidArgumentException